@@ -523,9 +523,10 @@ class Model:
                 name in self.__class__._INDEXES:
                 key_index = key_indexes + name
                 if value != None:
-                    pipe.zadd(key_index, self.__class__._score(value), self._id)
+                    pipe.zadd(key_index, self.__class__._score(value),
+                              str(self._id))
                 else:
-                    pipe.zrem(key_index, self._id)
+                    pipe.zrem(key_index, str(self._id))
 
             name = key + name
 
@@ -617,5 +618,5 @@ class Model:
         if keys_indexes:
             _ = SEP.join([self.__class__._serie_name(), __class__._S_INDEXES, ''])
             for name in keys_indexes:
-                R.zrem(_ + name, self._id)
+                R.zrem(_ + name, str(self._id))
         #.delete()
